===
dgo
===


.. image:: https://img.shields.io/pypi/v/dgo.svg
        :target: https://pypi.python.org/pypi/dgo

.. image:: https://img.shields.io/travis/daimon99/dgo.svg
        :target: https://travis-ci.com/daimon99/dgo

.. image:: https://readthedocs.org/projects/dgo/badge/?version=latest
        :target: https://dgo.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Shortcut cmds collection.


* Free software: MIT license
* Documentation: https://dgo.readthedocs.io.


Features
--------

* upload a file temporary.

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
